@@ -1,8 +1,17 @@
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage(
-    sprintf("SnakeCharmR %s - R and Python Integration\n", utils::packageVersion("SnakeCharmR")),
+    sprintf("%s %s - R and Python Integration\n", pkgname, utils::packageVersion(pkgname)),
     "Contribute and submit issues at https://github.com/asieira/SnakeCharmR\n",
-    paste("\nPython version", py.get("sys.version"))
+    paste(
+      "\nPython version", 
+      {
+        x = paste0(py.get("sys.version"), collapse = "\n");
+        if (!is.character(x) || length(x) != 1 || is.na(x)) 
+          x = paste0(sapply(0:2, function(x) py.get(sprintf("sys.version_info[%i]", x))),
+                     collapse = ".");
+        x
+      }
+    )
   )
 }
 
@@ -29,5 +38,9 @@
 }
 
 .py.fromJSON <- function(x, json.options = list()) {
+  if (is.raw(x)) {
+    x <- rawConnection(x)
+    on.exit(close(x))
+  }
   do.call(fromJSON, c(json.options, list(txt = x)))
 }
